@@ -6,14 +6,14 @@ library(knitr)
 library(glue)
 
 test_that("md_issue creates GitHub auto-link URL", {
-  issue <- md_issue("kiernann/gluedown", 1)
+  issue <- md_issue("k5cents/gluedown", 1)
   convert <- str_c("https://github.com/", str_replace(issue, "#", "/issues/"))
-  url <- "https://github.com/kiernann/gluedown/issues/1"
+  url <- "https://github.com/k5cents/gluedown/issues/1"
   expect_equal(convert, url)
 })
 
 test_that("md_issue returns error without issue number", {
-  expect_error(md_issue("kiernann/gluedown", "one"))
+  expect_error(md_issue("k5cents/gluedown", "one"))
 })
 
 test_that("md_issue returns error without correct repo format", {
